import React from "react";
import {
  Box,
  Text,
  Heading,
  Flex,
  Image,
  VStack,
  Grid,
  GridItem,
} from "@chakra-ui/react";
import { KYCDetails } from "../variables/interface";
import ImageWithFallback from "@/components/image/ImageWithFallback";

const KYCView = ({ kyc }: { kyc: KYCDetails }) => {
  const handleError = (e: React.SyntheticEvent<HTMLImageElement, Event>) => {
    e.currentTarget.src = "/img/dashboards/medianet_logo.png"; // Fallback image URL
  };
  return (
    <Box p="5" borderWidth="1px" borderRadius="lg" shadow="md">
      <Heading as="h2" size="lg" mb="4">
        KYC Details
      </Heading>
      <Grid templateColumns="repeat(2, 1fr)" gap={4}>
        <GridItem>
          <Text fontWeight="bold">Full Name:</Text>
          <Text>{kyc.full_name}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Contact Information:</Text>
          <Text>{kyc.contact_information}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Address:</Text>
          <Text>{kyc.address}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Meter No:</Text>
          <Text>{kyc.meter_no}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Premises Type:</Text>
          <Text>{kyc.premises_type}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Property Type:</Text>
          <Text>{kyc.property_type}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Latitude:</Text>
          <Text>{kyc.latitude}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Longitude:</Text>
          <Text>{kyc.longitude}</Text>
        </GridItem>
        <GridItem colSpan={2}>
          <Text fontWeight="bold">Created By:</Text>
          <Text>{`${kyc.created_by.first_name} ${kyc.created_by.last_name}`}</Text>
        </GridItem>
        <GridItem colSpan={2}>
          <Text fontWeight="bold">Created At:</Text>
          <Text>{new Date(kyc.created_at).toLocaleString()}</Text>
        </GridItem>
      </Grid>

      <VStack align="start" mt="6">
        <Heading as="h3" size="md" mb="2">
          Attachments
        </Heading>
        {kyc.attachments.length > 0 ? (
          <Flex gap="4" wrap="wrap">
            {kyc.attachments.map((attachment) => (
              <Box
                key={attachment.id}
                borderWidth="1px"
                borderRadius="md"
                p="2"
              >
                <ImageWithFallback attachment={attachment} />
                <Text mt="2" fontSize="sm">
                  {attachment.file.filename}
                </Text>
              </Box>
            ))}
          </Flex>
        ) : (
          <Text>No attachments available.</Text>
        )}
      </VStack>
    </Box>
  );
};

export default KYCView;
